@@ -1,9 +1,7 @@
-# aclint: py3
 import argparse
 import logging
 
-from revup import git
-from revup import topic_stack
+from revup import git, topic_stack
 from revup.types import GitConflictException
 
 
@@ -15,11 +13,11 @@ async def main(args: argparse.Namespace, git_ctx: git.Git) -> int:
         git_ctx,
         args.base_branch,
         args.relative_branch,
-        args.author,
         None,
         None,
     )
-    await topics.populate_topics(args.relative_chain, args.auto_topic)
+
+    await topics.populate_topics()
 
     try:
         await topics.restack(args.topicless_last)
