@@ -1,4 +1,3 @@
-# pylint: disable=too-many-lines
 from __future__ import annotations
 
 import logging
@@ -90,7 +89,7 @@ class PushStatus(Enum):
 
 
 @dataclass
-class Review:  # pylint: disable=too-many-instance-attributes
+class Review:
     """
     Represents a single github pull request. Uniquely keyed by topic name and base branch.
     """
@@ -192,6 +191,7 @@ class TopicStack:
     # Github access info
     github_ep: Optional[github.GitHubEndpoint] = None
     repo_info: Optional[github_utils.GitHubRepoInfo] = None
+    fork_info: Optional[github_utils.GitHubRepoInfo] = None
 
     # Original list of relevant commits given to the submitter
     commits: List[git.CommitHeader] = field(default_factory=list)
@@ -270,6 +270,7 @@ class TopicStack:
             review.push_status != PushStatus.PUSHED
             or review.status == PrStatus.MERGED
             or not self.repo_info
+            or not self.fork_info
             or review.pr_info is None
             or review.base_ref is None
         ):
@@ -311,7 +312,7 @@ class TopicStack:
                 # Non rebase push, diff against previous version of the branch
                 diff_base = review.pr_info.headRefOid
             diff = (
-                f"[diff](/{self.repo_info.owner}/{self.repo_info.name}/compare/"
+                f"[diff](/{self.fork_info.owner}/{self.repo_info.name}/compare/"
                 f"{diff_base}..{review.new_commits[-1]})"
             )
             summary = await self.git_ctx.get_diff_summary(diff_base, review.new_commits[-1])
@@ -324,9 +325,9 @@ class TopicStack:
 
         ret += (
             f"\r\n| {number} | [{review.new_commits[-1][:8]}]"
-            f"(/{self.repo_info.owner}/{self.repo_info.name}/commit/{review.new_commits[-1]}) "
+            f"(/{self.fork_info.owner}/{self.repo_info.name}/commit/{review.new_commits[-1]}) "
             f"| [{review.base_ref[:8]}]"
-            f"(/{self.repo_info.owner}/{self.repo_info.name}/commit/{review.base_ref}) "
+            f"(/{self.fork_info.owner}/{self.repo_info.name}/commit/{review.base_ref}) "
             f"| {diff} | {datetime.today().strftime('%b %d %-I:%M %p')} | {summary} |"
         )
         return PrComment(ret, orig.id if orig else None)
@@ -380,9 +381,9 @@ class TopicStack:
             if not parsed_tags[TAG_TOPIC]:
                 if auto_topic:
                     parsed_tags[TAG_TOPIC].add(
-                        "_".join(trimmed_msg.split()[:5]).translate(
-                            {ord(":"): None, ord("["): None, ord("]"): None}
-                        )
+                        "_".join(
+                            trimmed_msg.split("\n", maxsplit=1)[0].lower().split()[:5]
+                        ).translate({ord(":"): None, ord("["): None, ord("]"): None})
                     )
                 else:
                     # No topic tags, not a revup commit
@@ -404,7 +405,7 @@ class TopicStack:
         if len(self.topics) == 0:
             raise RevupUsageException(f"Found {len(self.commits)} commits but no topic tags!")
 
-    async def populate_reviews(  # pylint: disable=too-many-branches, too-many-statements, too-many-locals
+    async def populate_reviews(
         self,
         uploader: str,
         force_relative_chain: bool = False,
@@ -592,7 +593,7 @@ class TopicStack:
 
             seen_topics[name] = topic
 
-    async def mark_rebases(self, skip_rebase: bool) -> None:  # pylint: disable=too-many-statements
+    async def mark_rebases(self, skip_rebase: bool) -> None:
         """
         Scan all topics and compare patch-ids to remote patch-ids. Appropriately mark any
         changes that are already merged, or where push can be skipped due to being rebases or
@@ -1135,7 +1136,7 @@ class TopicStack:
         """
         Actually perform the github graphql PR creation
         """
-        if not self.github_ep or not self.repo_info or not self.repo_id:
+        if not self.github_ep or not self.repo_info or not self.fork_info or not self.repo_id:
             raise RuntimeError("Can't update without github info")
 
         prs_to_create = []
@@ -1146,13 +1147,15 @@ class TopicStack:
         if prs_to_create:
             # Create all prs in one request. These will most likely end up being modified
             # later since its not possible to add labels or reviewers at creation time.
-            await github_utils.create_pull_requests(self.github_ep, self.repo_id, prs_to_create)
+            await github_utils.create_pull_requests(
+                self.github_ep, self.repo_id, self.repo_info, self.fork_info, prs_to_create
+            )
 
     async def update_prs(self) -> None:
         """
         Actually perform the github graphql PR updates
         """
-        if not self.github_ep or not self.repo_info or not self.repo_id:
+        if not self.github_ep or not self.repo_info or not self.fork_info or not self.repo_id:
             raise RuntimeError("Can't update without github info")
 
         prs_to_update = []
@@ -1160,7 +1163,7 @@ class TopicStack:
             if not review.pr_info:
                 continue
             if (
-                review.pr_update.baseRef is not None  # pylint: disable=too-many-boolean-expressions
+                review.pr_update.baseRef is not None
                 or review.pr_update.body is not None
                 or review.pr_update.title is not None
                 or review.pr_update.reviewer_ids
